@@ -32,6 +32,22 @@ case $TERM in
         ;;
 esac
 
+#   find some random files
+#   (do not use /dev/random here, because this device 
+#   doesn't work as expected on all platforms)
+randfiles=''
+for file in /var/log/messages /var/adm/messages \
+            /kernel /vmunix /vmlinuz \
+            /etc/hosts /etc/resolv.conf; do
+    if [ -f $file ]; then
+        if [ ".$randfiles" = . ]; then
+            randfiles="$file"
+        else
+            randfiles="${randfiles}:$file"
+        fi
+    fi
+done
+
 #   processing
 case $type in
 
@@ -65,8 +81,8 @@ case $type in
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating RSA private key (1024 bit) [server.key]${T_ME}"
-        if [ -r /dev/random ]; then
-            $ssleay genrsa -rand /dev/random:/dev/random:/dev/random \
+        if [ ".$randfiles" != . ]; then
+            $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/server.key \
                            1024
         else
@@ -171,8 +187,8 @@ EOT
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating RSA private key for CA (1024 bit)${T_ME}"
-        if [ -r /dev/random ]; then
-            $ssleay genrsa -rand /dev/random:/dev/random:/dev/random \
+        if [ ".$randfiles" != . ]; then
+            $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/ca.key \
                            1024
         else
@@ -233,8 +249,8 @@ EOT
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 4: Generating RSA private key for SERVER (1024 bit)${T_ME}"
-        if [ -r /dev/random ]; then
-            $ssleay genrsa -rand /dev/random:/dev/random:/dev/random \
+        if [ ".$randfiles" != . ]; then
+            $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/server.key \
                            1024
         else
